# Processes

Whenever a workflow is started, this creates a process with all relevant information from the workflow. Therefore, all fields are read-only.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Workflow:
The executed workflow.

### UUID:
Unique identifier for this process.

### Started:
Date and time at which the workflow was started.

### Finished:
Date and time at which the workflow was finished.

### Attached Model:
The model the workflow is attached to (e.g. Activity). Used to display buttons in the model instances to steer the workflow, set a status field or evaluate conditions.

## Legend:
Click on a state in the legend to filter the list.

## Filters:
Filters are accessed by clicking on the symbol in the top left corner of the window.

### States:
Filter processes by a specific state they're in, smiliarly to what clicking on the legend does.

## Search Field:
Typing in the search field allows to filter the processes by workflow name or attached model.
